---
title: About Index Pages
---
# Introduction

!!! question inline end "Help documentation :arrow_upper_right:"
    The help icon in the top-most menu shows all help documentation.

!!! note "Content menu :arrow_up:"
    The `Content` menu above allows you to create new documentation and review existing documentation.

:arrow_upper_left: You can rename the site title by hovering your mouse over "Your Documentation Site."

## Editing this document

You can edit this document for your own purposes.  The `Content` menu above allows you to create more pages.

### Shortcuts

This document will cover some shortcuts.

- :penguin:Linux and Windows will have shortcuts with `Ctrl` key.
- :apple: MacOS uses the same shortcuts but with the `CMD` key.

For example, on Linux `Ctrl+C` is copy and on Mac the shortcut is `CMD+C`.  All shortcuts from here on out will be listed with `Ctrl` but you can interchange `CMD` with `Ctrl` for every shortcut.

### Focus Mode

You can collapse menus in upper left menu.

Helpful shortcuts:

- Keyboard shortcut `Ctrl+Shift+F` to toggle for focused content.  As you edit, the content continuously auto-saves.
- `Ctrl+.` (Ctrl period) switches this document between WYSIWYG and Markdown modes.

## Automatic table of contents

!!! info inline end "Table of contents on the right :arrow_right:"
    The table of contents allows for quick navigation inside of the currently opened document.

In `mkdocs`, the table of contents automatically populates if all sections below the first section is H2 through H6.  The top level [Introduction](#introduction) is H1.  If you find your table of contents no longer renders, then it is because there are other H1 sections in the document by mistake which would break automatic table of contents in rendering.  This is a `mkdocs` quirk and not related to this editor.

## Nav Menu

!!! abstract inline ":arrow_left: Nav menu on the left"
    The Nav menu allows you to reorganize content, view other pages, and present sections of your documentation.

Nav menu has contextual help:

1. `Ctrl+Click` on About Index Pages.
2. With a file selected you can run keyboard shortcut `Ctrl+?` which will bring up contextual help documentation.
